'use strict'
const merge = require('webpack-merge')
const ExtractTextPlugin = require('extract-text-webpack-plugin')
const OptimizeCSSPlugin = require('optimize-css-assets-webpack-plugin')
const UglifyJsPlugin = require('uglifyjs-webpack-plugin')
const { resolve } = require('path')

const config = {
  output: {
    path: resolve(__dirname, '../dist/')
  },
  entry: '../src/index.js',
  resolve: {
    extensions: ['.js', '.vue', '.css'],
    alias: {
      'src': resolve(__dirname, '../src')
    }
  },
  module: {
    loaders: [
      {
        test: /\.vue$/,
        loader: 'vue-loader',
        options: {
          extractCSS: true,
          cssSourceMap: true
        }
      },
      {
        test: /\.js$/,
        loader: 'babel-loader',
        include: [
          resolve(__dirname, '../src')
        ],
        exclude: /node_modules/
      },
      {
        test: /\.css$/,
        loader: 'ignore-loader',
        include: /node_modules/
      }
    ]
  },
  externals: {
    'vue': 'Vue',
    'shufflejs': 'Shuffle',
    'imagesloaded': 'imagesLoaded',
    'vue-multiselect': 'Multiselect'
  },
  plugins: [
    new UglifyJsPlugin({
      uglifyOptions: {
        compress: {
          warnings: false
        }
      },
      parallel: true,
      sourceMap: true
    }),
    // Extracted & non minified css
    new ExtractTextPlugin('vue-shufflejs-plugin.css'),
    // Extracted css for minifying
    new ExtractTextPlugin('vue-shufflejs-plugin.min.css'),
    // Minify extracted css
    new OptimizeCSSPlugin({
      assetNameRegExp: /\.min\.css$/g,
      cssProcessorOptions: { safe: true, map: { inline: false } }
    })
  ]
}

module.exports = [
  merge(config, {
    entry: resolve(__dirname, '../src/index.js'),
    output: {
      filename: 'vue-shufflejs-plugin.min.js',
      libraryTarget: 'window',
      library: 'VueShuffle'
    }
  }),
  merge(config, {
    entry: resolve(__dirname, '../src/components/VueShuffle.vue'),
    output: {
      filename: 'vue-shufflejs-plugin.js',
      libraryTarget: 'umd',
      library: 'VueShuffle',
      umdNamedDefine: true
    }
  }),
  merge(config, {
    entry: resolve(__dirname, '../src/components/VueShuffle.vue'),
    output: {
      filename: 'vue-shufflejs-plugin.common.js',
      libraryTarget: 'commonjs2',
      library: 'VueShuffle'
    }
  })
]
