import Vue from 'vue'

/**
 * Shuffle item attributes directive
 * Set shuffle specific data attributes for filtering, sorting or searching
 *
 * Usage:
 * const attr = {
 *                color: [
 *                  {id: 1, value: 'red'},
 *                  {id: 2, value: 'green'}
 *                ]
 *                size: {
 *                  {id: 1, value: 'large'},
 *                  {id: 2, value: 'small'}
 *                }
 *              }
 *
 * <div v-shuffle-item-attributes="{ attributes: attr }"></div>
 *
 * Result:
 * <div data-color="["red","green"]" data-size="["large","small"]"></div>
 */
const ShuffleItemAttributes = {
  bind (el, binding, vnode, oldVnode) {
    const attributes = binding.value.attributes
    // With default attribute filter
    // el.setAttribute('data-groups', JSON.stringify(attributes))
    for (const prop in attributes) {
      const attr = []
      attributes[prop].forEach((attribute) => {
        attr.push(attribute.name)
      })
      el.setAttribute('data-' + prop, JSON.stringify(attr))
    }
  }
}

export default ShuffleItemAttributes
Vue.directive('shuffle-item-attributes', ShuffleItemAttributes)
