import VueShuffle from './components/VueShuffle'
import VueShuffleNavbar from './components/VueShuffleNavbar'
import VueShuffleGrid from './components/VueShuffleGrid'
import LoadingIndicator from './components/LoadingIndicator'

import ShuffleItemAttributes from './directives/shuffle-item-attributes'

import { sanitize } from './filters'

import 'intersection-observer'

const VueShuffleJsPlugin = {
  install (Vue, options) {
    /**
     * Add filters
     */
    Vue.filter('sanitize', sanitize)

    /**
     * Install plugin components
     */
    Vue.component(VueShuffle.name, VueShuffle)
    Vue.component(VueShuffleNavbar.name, VueShuffleNavbar)
    Vue.component(VueShuffleGrid.name, VueShuffleGrid)
    Vue.component(LoadingIndicator.name, LoadingIndicator)

    /**
     * Install plugin directives
     */
    Vue.directive('shuffle-item-attributes', ShuffleItemAttributes)

    /**
     * Add component lifecycle hooks or properties
     * Call Vue.mixin() here to inject functionality into all components
     * Anything added to a mixin will be injected into all components
     * created() method runs when the component is created
     * mounted() method runs when the component is added to the DOM
     */
    /* Vue.mixin({
      created () {
        console.log('component created...', this)
      },
      mounted () {
        console.log('component mounted...', this)
      }
    }) */
  }
}

/**
 * Automatic installation if Vue has been added to the global scope
 */
if (typeof window !== 'undefined' && window.Vue) {
  window.Vue.use(VueShuffleJsPlugin)
}

export default VueShuffleJsPlugin
